import createKeccakHash from "keccak";
export class Address {
    constructor(buffer) {
        this.buffer = buffer;
    }
    static toAddress(publicKey) {
        const address = createKeccakHash("keccak256")
            .update(publicKey)
            .digest()
            .slice(12, 32);
        return address;
    }
    static fromPublicKey(publicKey) {
        if (publicKey.length !== 64) {
            throw TypeError(`Address: invalid public key. buffer length must be 64. actual: ${publicKey.length}`);
        }
        return new Address(this.toAddress(publicKey));
    }
    toChecksumAddress(address) {
        // EIP-55 https://github.com/ethereum/EIPs/blob/master/EIPS/eip-55.md#implementation
        const hash = createKeccakHash("keccak256").update(address).digest("hex");
        return address
            .split("")
            .map((c, i) => {
            return Number.parseInt(hash[i], 16) > 7 ? c.toUpperCase() : c;
        })
            .join("");
    }
    toString() {
        return this.toChecksumAddress(this.buffer.toString("hex"));
    }
    equals(other) {
        return this.buffer.equals(other.buffer);
    }
}
